@@ -33,7 +33,7 @@ def dataset_orgs():
 
 def taxa_to_exclude():
     to_skip = set()
-    with open(args.to_exclude, 'w') as infile:
+    with open(args.to_exclude, 'r') as infile:
         for line in infile:
             unique_id = line.strip().split(',')[0]
             to_skip.add(unique_id)
@@ -209,22 +209,12 @@ def add_to_meta(abbrev):
                'Higher Taxonomy': input_info[abbrev]['tax'].replace('*', ''),
                'Lower Taxonomy': input_info[abbrev]['subtax'].replace('*', ''),
                'Data Type': input_info[abbrev]['data_type'],
-               'Notes': input_info[abbrev]['notes']
+               'Source': input_info[abbrev]['notes']
                }
 
-    taxa_comp, gene_count = tools.completeness(args, str(Path(dfo, f'orthologs/')), genes=False)
-    bin_matrix = tools.completeness(args, str(Path(dfo, f'orthologs/')), genes=True)
-    taxa_comp = taxa_comp.to_dict()
-
     df = pd.read_csv(metadata, delimiter='\t')
-    print(df)
     df.index = df['Unique ID']
 
-    comp_list = [taxa_comp[ind] if ind in taxa_comp else 0 for ind in df.index]
-    df['Completeness'] = comp_list
-    df['Completeness'] = df['Completeness'] * 100
-    df['Completeness'] = df['Completeness'].round(2)
-
     df = df.append(new_row, ignore_index=True)
     df = df.sort_values(by=['Higher Taxonomy', 'Lower Taxonomy', 'Unique ID'])
     df.to_csv(str(Path(dfo, 'metadata.tsv')), sep='\t', index=False)
@@ -309,14 +299,13 @@ def main():
         new_database(table)
 
     rebuild_db()
-
-    matrix = tools.completeness(args, f'{dfo}/orthologs')
-    matrix.to_csv(f'{dfo}/bin_matrix.tsv', sep='\t')
     cp_proteomes()
 
 
 if __name__ == '__main__':
-    desc = ''
+    desc = ('Apply parsing decisions and add new data to the database. \n\n'
+            'NOTE: If apply_to_db.py fails for any reason, see backup_resoration.py \n'
+            ' and restore you database from the proper backup')
     parser, optional, required = help_formatter.initialize_argparse(name='apply_to_db.py',
                                                                     desc=desc,
                                                                     usage="apply_to_db.py -i <in_dir>")
